<?php
/*
 * Plugin name:	SEO Social Booster
 * Description: SEO Social Network, allowing exchange backlinks and article links between websites and community members
 * Version: 1.9
 * Author: Website and Brand Building Agency - Origin Ten LTD
 * Author URI: https://originten.co.uk
 * License: GPL
 */

/**/


defined( 'ABSPATH' ) || exit;

/**
 * Adding WP List table class if it's not available.
 */
if ( ! class_exists( \WP_List_Table::class ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}
if ( ! class_exists( \seoboosterlist::class ) ) {
	require_once  plugin_dir_path( __FILE__ ) . '/includes/table_listing.php';
}


if( ! class_exists( 'seoboosterUpdateChecker' ) ) {

	class seoboosterUpdateChecker{

		public $plugin_slug;
		public $version;
		public $cache_key;
		public $cache_allowed;
		public $site_key;
		public function __construct() {

			$this->plugin_slug = plugin_basename( __DIR__ );
			$this->version = '1.9';
			$this->cache_key = 'seosocialbooster_custom_upd';
			$this->cache_allowed = false;
			$this->name = 'seo-social-booster'; // Plugin Folder
			$this->displayName	= 'SEO Booster'; // Plugin Name
			$this->dir_path=  plugin_dir_path( __FILE__ )  ;

			add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
			add_action( 'admin_init', array( &$this, 'registerSeobooster' ) );
			add_action( 'admin_menu', array( &$this, 'adminPanelsAndMetaBoxes' ) );
			add_filter( 'site_transient_update_plugins', array( $this, 'update' ) );
			add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );
			add_action( 'admin_action_updatetonetwork',array( $this , 'update_to_network' ) );
			add_action( 'admin_action_updatekeywords',array( $this , 'update_keywords' ) );
			add_action( 'admin_action_addtonetwork',array( $this , 'add_to_network' ) );
			add_action( 'admin_action_removefromnetwork',array( $this , 'remove_from_network' ) );
			add_action( 'isa_add_every_three_minutessseo', array( $this , 'every_three_minutes_event_funcseo' )  );
			add_filter( 'cron_schedules', array( $this , 'isa_add_every_three_minutessseo' ) );
			add_filter('the_content',  array( $this , 'add_content_after' ));
			
			// Schedule an action if it's not already scheduled
			if ( ! wp_next_scheduled( 'isa_add_every_three_minutessseo' ) ) {
				wp_schedule_event( time(), 'every_three_minutesseo', 'isa_add_every_three_minutessseo' );
			}
			add_action( 'wp_footer', array( $this, 'seosocialboosterfooter' ) );
		}	
		function seosocialboosterfooter(){
			$back_links = json_decode(get_option('seo_sociol_booster_backlinks'), true);
			$curent_url=get_permalink( get_the_ID());
			$back_link_text='<div class="origintenfooter" style=" background-color: #141618; padding:10px;">';
			$back_link_text.='<span style=" color:#fff">Power by <a href="https://originten.co.uk/free-seo-booster/" style="color:#fff">SEO Booster</a></span>';
			foreach($back_links as $link){
				
				$back_link_url = $link['url'];
				$back_link_keyword =  $link['keyword'];
				$back_link_target =  $link['target'];
				$back_link_trigger =  $link['trigger'];
				
				
				if($back_link_target !='content' and ($back_link_trigger =='all' or $back_link_trigger ==$curent_url)){
					$back_link_text .='<a href="'.$back_link_url.'" target="_blank" style="border:1px solid #fff;font-size: 12px; color:#fff; display: inline-block; text-align: center;margin: 10px;padding:10px;">'.$back_link_keyword .'</a>';
				}
				
			}
			$back_link_text .='</div>';
			echo $back_link_text;
		}
		function targetContentReplacment($content){
			$back_links = json_decode(get_option('seo_sociol_booster_backlinks'), true);
			$curent_url=get_permalink( get_the_ID());
			foreach($back_links as $link){
					
				$back_link_url = $link['url'];
				$back_link_keyword =  $link['keyword'];
				$back_link_target =  $link['target'];
				$back_link_syntax =  $link['syntax'];
				$back_link_trigger =  $link['trigger'];
				
				if($back_link_target =='content' and ($back_link_trigger =='all' or $back_link_trigger ==$curent_url)){
					$content =str_replace($back_link_syntax,"<a href='".$back_link_url."' target='_blank'>".$back_link_keyword."</a>",$content);
				}
			}
			
			return $content;
		}
		function add_content_after($content) {

			 
			    $fullcontent = $this->targetContentReplacment( $content);

			

			   return $fullcontent;

		}
		function isa_add_every_three_minutessseo( $schedules ) {
			$schedules['every_three_minutesseo'] = array(
					'interval'  => (60*60*10),
					'display'   => __( 'Every 3 Minutes SEO', 'textdomain' )
			);
			return $schedules;
		}
		
		function every_three_minutes_event_funcseo() {
					if (get_option('seo_sociol_booster_key')) {
						$this->site_key = get_option('seo_sociol_booster_key');
					}else{
						$this->site_key ='0';
					}
			
			 $remote = wp_remote_get(
					'https://originten.co.uk/plugins/get_backlinks.php?site_id='.urlencode($this->site_key),
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}
			
					if (!get_option('seo_sociol_booster_backlinks')) {	
						add_option( 'seo_sociol_booster_backlinks', wp_remote_retrieve_body( $remote ));
					}else{
						update_option( 'seo_sociol_booster_backlinks', wp_remote_retrieve_body( $remote ));
					}
				
		}	
		
		function update_to_network()
		{
			$message_code=1;
			$page_id = $_POST['page_id'];
	
			$remote = wp_remote_get(
					'https://originten.co.uk/plugins/update_url.php?site_id='.urlencode($this->site_key).'&page_id='.urlencode($page_id).'&status=true',
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					$message_code=0;
				}else{
					$remote = json_decode( wp_remote_retrieve_body( $remote ) );
					
					if($remote->updated !='ok'){
						$message_code=0;
					}
				}			
				
		
				wp_safe_redirect('options-general.php?page=seo-social-booster&msg=' . $message_code);
			
			
		}
		function add_to_network()
		{	
			$message_code=1;
			$page_id = $_POST['page_id'];			
			$post_title = $_POST['post_title'];
			$post_permalink = $_POST['post_permalink'];
			$post_type = $_POST['post_type'];
		
			$remote = wp_remote_get(
					'https://originten.co.uk/plugins/register_url.php?site_id='.urlencode($this->site_key).'&post_title='.urlencode($post_title).'&post_permalink='.urlencode($post_permalink).'&post_type='.urlencode($post_type ).'&post_id='.urlencode($page_id),
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					$message_code=0;
				}else{
					$remote = json_decode( wp_remote_retrieve_body( $remote ) );
					
					if($remote->page_id =='error'){
						$message_code=0;
					}
					if($remote->page_id =='dup'){
						$message_code=5;
					}
				}
				
				wp_safe_redirect('options-general.php?page=seo-social-booster&msg=' . $message_code);
		}
		function update_keywords()
		{
				$message_code=2;
			$page_id = $_POST['page_id'];
			$post_title = $_POST['post_title'];
			
			$remote = wp_remote_get(
					'https://originten.co.uk/plugins/update_url.php?site_id='.urlencode($this->site_key).'&page_id='.urlencode($page_id).'&post_title='.urlencode($post_title),
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					$message_code=0;
				}else{
					$remote = json_decode( wp_remote_retrieve_body( $remote ) );
					
					if($remote->updated !='ok'){
						$message_code=0;
					}
				}			
				
		
				wp_safe_redirect('options-general.php?page=seo-social-booster&msg=' . $message_code);
			
		}
		function remove_from_network()
		{
			$message_code=3;
			// Do your stuff here
			$page_id = $_POST['page_id'];
			
			$remote = wp_remote_get(
					'https://originten.co.uk/plugins/update_url.php?site_id='.urlencode($this->site_key).'&page_id='.urlencode($page_id),
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					$message_code=0;
				}else{
					$remote = json_decode( wp_remote_retrieve_body( $remote ) );
					
					if($remote->updated !='ok'){
						$message_code=0;
					}
				}			
				
		
				wp_safe_redirect('options-general.php?page=seo-social-booster&msg=' . $message_code);
				
		
		}

		function registerSeobooster() {
			
			if (!get_option('seo_sociol_booster_key')) {
			
			 $site_url= get_site_url( null, $path, $scheme );
			 $site_title = get_bloginfo( 'name' ); 
			 $site_email = get_bloginfo('admin_email');
		
			
			
			 $remote = wp_remote_get(
					'https://originten.co.uk/plugins/register_app.php?plugin=seo-social-booster&site_name='.urlencode( $site_title).'&site_admin_email='.urlencode( $site_email).'&site_url='.urlencode( $site_url),
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
				
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}
				$remote = json_decode( wp_remote_retrieve_body( $remote ) );
				if(isset($remote->key)){
					 add_option( 'seo_sociol_booster_key', $remote->key);
					 add_option( 'seo_sociol_booster_backlinks', $remote->social_backlinks);
					 $this->site_key = $remote->key;
				}
				
			
			}else{
				$this->site_key = get_option('seo_sociol_booster_key');
			}
			
		}
		function adminPanelsAndMetaBoxes() {
			add_submenu_page( 'options-general.php', $this->displayName, $this->displayName, 'manage_options', $this->name, array( &$this, 'adminPanel' ) );
		}
		function adminPanel() {
			$this->every_three_minutes_event_funcseo();
			include_once( $this->dir_path . '/views/settings.php' );
		}
		public function request(){

			$remote = get_transient( $this->cache_key );

			if( false === $remote || ! $this->cache_allowed ) {

				$remote = wp_remote_get(
					'https://originten.co.uk/plugins/info.php?plugin=seo-social-booster',
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);

				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}

				set_transient( $this->cache_key, $remote, DAY_IN_SECONDS );

			}

			$remote = json_decode( wp_remote_retrieve_body( $remote ) );

			return $remote;

		}


		function info( $res, $action, $args ) {

			// print_r( $action );
			// print_r( $args );

			// do nothing if you're not getting plugin information right now
			if( 'plugin_information' !== $action ) {
				return false;
			}

			// do nothing if it is not our plugin
			if( $this->plugin_slug !== $args->slug ) {
				return false;
			}

			// get updates
			$remote = $this->request();

			if( ! $remote ) {
				return false;
			}

			$res = new stdClass();

			$res->name = $remote->name;
			$res->slug = $remote->slug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = $remote->author;
			$res->author_profile = $remote->author_profile;
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;
			$res->last_updated = $remote->last_updated;

			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
			);

			if( ! empty( $remote->banners ) ) {
				$res->banners = array(
					'low' => $remote->banners->low,
					'high' => $remote->banners->high
				);
			}

			return $res;

		}

		public function update( $transient ) {

			if ( empty($transient->checked ) ) {
				return $transient;
			}

			$remote = $this->request();

			if(
				$remote
				&& version_compare( $this->version, $remote->version, '<' )
				&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<' )
				&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
			) {
				$res = new stdClass();
				$res->slug = $this->plugin_slug;
				$res->plugin = plugin_basename( __FILE__ ); // seo-social-booster/seo-social-booster.php
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url;

				$transient->response[ $res->plugin ] = $res;

	    }

			return $transient;

		}

		public function purge(){

			if (
				$this->cache_allowed
				&& 'update' === $options['action']
				&& 'plugin' === $options[ 'type' ]
			) {
				// just clean the cache when new plugin version is installed
				delete_transient( $this->cache_key );
			}

		}


	}

	new seoboosterUpdateChecker();

}